@@ -147,7 +147,8 @@ func FQDNHostname(fileSystem vfs.FS) (string, error) {
 
 	// Otherwise, if we're on OpenBSD, try /etc/myname.
 	if runtime.GOOS == "openbsd" {
-		if fqdnHostname, err := etcMynameFQDNHostname(fileSystem); err == nil && fqdnHostname != "" {
+		if fqdnHostname, err := etcMynameFQDNHostname(fileSystem); err == nil &&
+			fqdnHostname != "" {
 			return fqdnHostname, nil
 		}
 	}
@@ -208,7 +209,9 @@ func SuspiciousSourceDirEntry(base string, fileInfo fs.FileInfo, encryptedSuffix
 			return true
 		}
 		for _, encryptedSuffix := range encryptedSuffixes {
-			if fileAttr := parseFileAttr(fileInfo.Name(), encryptedSuffix); knownTargetFiles.contains(fileAttr.TargetName) {
+			if fileAttr := parseFileAttr(fileInfo.Name(), encryptedSuffix); knownTargetFiles.contains(
+				fileAttr.TargetName,
+			) {
 				return true
 			}
 		}
