@@ -6,7 +6,7 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-vfs/v4/vfst"
 
@@ -25,7 +25,7 @@ func TestImportCmd(t *testing.T) {
 			},
 		},
 	})
-	require.NoError(t, err)
+	assert.NoError(t, err)
 
 	for _, tc := range []struct {
 		args      []string
@@ -139,10 +139,10 @@ func TestImportCmd(t *testing.T) {
 				"/home/user": &vfst.Dir{Perm: fs.ModePerm},
 			}, func(fileSystem vfs.FS) {
 				if tc.extraRoot != nil {
-					require.NoError(t, vfst.NewBuilder().Build(fileSystem, tc.extraRoot))
+					assert.NoError(t, vfst.NewBuilder().Build(fileSystem, tc.extraRoot))
 				}
 				config := newTestConfig(t, fileSystem, withStdin(bytes.NewReader(data)))
-				require.NoError(t, config.execute(append([]string{"import"}, tc.args...)))
+				assert.NoError(t, config.execute(append([]string{"import"}, tc.args...)))
 				vfst.RunTests(t, fileSystem, "", tc.tests...)
 			})
 		})
