@@ -28,7 +28,13 @@ func cgoGetUserShell(name string) (string, bool) {
 			buf    = make([]byte, buflen)
 			result *C.struct_passwd
 		)
-		rc := C.getpwnam_r(cName, &pwd, (*C.char)(unsafe.Pointer(&buf[0])), C.size_t(buflen), &result) //nolint:gocritic
+		rc := C.getpwnam_r(
+			cName,
+			&pwd,
+			(*C.char)(unsafe.Pointer(&buf[0])),
+			C.size_t(buflen),
+			&result, //nolint:gocritic
+		)
 		C.free(unsafe.Pointer(cName))
 
 		switch rc {
